==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RegistrationInlineHookPPDataAllOfData.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.RegistrationInlineHookPPDataAllOfDataContext;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RegistrationInlineHookPPDataAllOfData
 */
@JsonPropertyOrder({ RegistrationInlineHookPPDataAllOfData.JSON_PROPERTY_CONTEXT,
        RegistrationInlineHookPPDataAllOfData.JSON_PROPERTY_ACTION,
        RegistrationInlineHookPPDataAllOfData.JSON_PROPERTY_USER_PROFILE_UPDATE })
@JsonTypeName("RegistrationInlineHookPPData_allOf_data")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class RegistrationInlineHookPPDataAllOfData implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTEXT = "context";
    private RegistrationInlineHookPPDataAllOfDataContext context;

    public static final String JSON_PROPERTY_ACTION = "action";
    private String action;

    public static final String JSON_PROPERTY_USER_PROFILE_UPDATE = "userProfileUpdate";
    private Map<String, Object> userProfileUpdate = null;

    public RegistrationInlineHookPPDataAllOfData() {
    }

    public RegistrationInlineHookPPDataAllOfData context(RegistrationInlineHookPPDataAllOfDataContext context) {

        this.context = context;
        return this;
    }

    /**
     * Get context
     *
     * @return context
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RegistrationInlineHookPPDataAllOfDataContext getContext() {
        return context;
    }

    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContext(RegistrationInlineHookPPDataAllOfDataContext context) {
        this.context = context;
    }

    public RegistrationInlineHookPPDataAllOfData action(String action) {

        this.action = action;
        return this;
    }

    /**
     * The default action the system takes. Set to &#x60;ALLOW&#x60;. &#x60;DENY&#x60; is never sent to your external
     * service
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The default action the system takes. Set to `ALLOW`. `DENY` is never sent to your external service")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(String action) {
        this.action = action;
    }

    public RegistrationInlineHookPPDataAllOfData userProfileUpdate(Map<String, Object> userProfileUpdate) {

        this.userProfileUpdate = userProfileUpdate;
        return this;
    }

    public RegistrationInlineHookPPDataAllOfData putuserProfileUpdateItem(String key, Object userProfileUpdateItem) {
        if (this.userProfileUpdate == null) {
            this.userProfileUpdate = new HashMap<>();
        }
        this.userProfileUpdate.put(key, userProfileUpdateItem);
        return this;
    }

    /**
     * Name-value pairs for each new attribute supplied by the user in the Progressive Profile form
     *
     * @return userProfileUpdate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Name-value pairs for each new attribute supplied by the user in the Progressive Profile form")
    @JsonProperty(JSON_PROPERTY_USER_PROFILE_UPDATE)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)

    public Map<String, Object> getUserProfileUpdate() {
        return userProfileUpdate;
    }

    @JsonProperty(JSON_PROPERTY_USER_PROFILE_UPDATE)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)
    public void setUserProfileUpdate(Map<String, Object> userProfileUpdate) {
        this.userProfileUpdate = userProfileUpdate;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RegistrationInlineHookPPDataAllOfData registrationInlineHookPPDataAllOfData = (RegistrationInlineHookPPDataAllOfData) o;
        return Objects.equals(this.context, registrationInlineHookPPDataAllOfData.context)
                && Objects.equals(this.action, registrationInlineHookPPDataAllOfData.action)
                && Objects.equals(this.userProfileUpdate, registrationInlineHookPPDataAllOfData.userProfileUpdate);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(context, action, userProfileUpdate);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RegistrationInlineHookPPDataAllOfData {\n");
        sb.append("    context: ").append(toIndentedString(context)).append("\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    userProfileUpdate: ").append(toIndentedString(userProfileUpdate)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RegistrationInlineHookPPDataAllOfData.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.RegistrationInlineHookPPDataAllOfDataContext;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RegistrationInlineHookPPDataAllOfData
 */
@JsonPropertyOrder({ RegistrationInlineHookPPDataAllOfData.JSON_PROPERTY_CONTEXT,
        RegistrationInlineHookPPDataAllOfData.JSON_PROPERTY_ACTION,
        RegistrationInlineHookPPDataAllOfData.JSON_PROPERTY_USER_PROFILE_UPDATE })
@JsonTypeName("RegistrationInlineHookPPData_allOf_data")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class RegistrationInlineHookPPDataAllOfData implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTEXT = "context";
    private RegistrationInlineHookPPDataAllOfDataContext context;

    public static final String JSON_PROPERTY_ACTION = "action";
    private String action;

    public static final String JSON_PROPERTY_USER_PROFILE_UPDATE = "userProfileUpdate";
    private Map<String, Object> userProfileUpdate = null;

    public RegistrationInlineHookPPDataAllOfData() {
    }

    public RegistrationInlineHookPPDataAllOfData context(RegistrationInlineHookPPDataAllOfDataContext context) {

        this.context = context;
        return this;
    }

    /**
     * Get context
     *
     * @return context
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RegistrationInlineHookPPDataAllOfDataContext getContext() {
        return context;
    }

    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContext(RegistrationInlineHookPPDataAllOfDataContext context) {
        this.context = context;
    }

    public RegistrationInlineHookPPDataAllOfData action(String action) {

        this.action = action;
        return this;
    }

    /**
     * The default action the system takes. Set to &#x60;ALLOW&#x60;. &#x60;DENY&#x60; is never sent to your external
     * service
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The default action the system takes. Set to `ALLOW`. `DENY` is never sent to your external service")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(String action) {
        this.action = action;
    }

    public RegistrationInlineHookPPDataAllOfData userProfileUpdate(Map<String, Object> userProfileUpdate) {

        this.userProfileUpdate = userProfileUpdate;
        return this;
    }

    public RegistrationInlineHookPPDataAllOfData putuserProfileUpdateItem(String key, Object userProfileUpdateItem) {
        if (this.userProfileUpdate == null) {
            this.userProfileUpdate = new HashMap<>();
        }
        this.userProfileUpdate.put(key, userProfileUpdateItem);
        return this;
    }

    /**
     * Name-value pairs for each new attribute supplied by the user in the Progressive Profile form
     *
     * @return userProfileUpdate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Name-value pairs for each new attribute supplied by the user in the Progressive Profile form")
    @JsonProperty(JSON_PROPERTY_USER_PROFILE_UPDATE)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)

    public Map<String, Object> getUserProfileUpdate() {
        return userProfileUpdate;
    }

    @JsonProperty(JSON_PROPERTY_USER_PROFILE_UPDATE)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)
    public void setUserProfileUpdate(Map<String, Object> userProfileUpdate) {
        this.userProfileUpdate = userProfileUpdate;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RegistrationInlineHookPPDataAllOfData registrationInlineHookPPDataAllOfData = (RegistrationInlineHookPPDataAllOfData) o;
        return Objects.equals(this.context, registrationInlineHookPPDataAllOfData.context)
                && Objects.equals(this.action, registrationInlineHookPPDataAllOfData.action)
                && Objects.equals(this.userProfileUpdate, registrationInlineHookPPDataAllOfData.userProfileUpdate);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(context, action, userProfileUpdate);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RegistrationInlineHookPPDataAllOfData {\n");
        sb.append("    context: ").append(toIndentedString(context)).append("\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    userProfileUpdate: ").append(toIndentedString(userProfileUpdate)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
